summaryrefslogtreecommitdiffstats
path: root/kdat/BackupProfileWidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit93910780efc46524d0f2c6693784b3fa10d26985 (patch)
treee44cc42ad795bb8399c6558bf8af3887c966fd49 /kdat/BackupProfileWidget.h
parent4a25ca5c80d9b88fdc1a0d44d1db47da47206899 (diff)
downloadtdeadmin-93910780efc46524d0f2c6693784b3fa10d26985.tar.gz
tdeadmin-93910780efc46524d0f2c6693784b3fa10d26985.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeadmin@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdat/BackupProfileWidget.h')
-rw-r--r--kdat/BackupProfileWidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/BackupProfileWidget.h b/kdat/BackupProfileWidget.h
index 4458c38..11526fe 100644
--- a/kdat/BackupProfileWidget.h
+++ b/kdat/BackupProfileWidget.h
@@ -57,10 +57,10 @@ public:
*
* @param archiveName The default name for the new archive.
* @param files The list of files to be archived.
* @param tqparent The tqparent widget of this dialog.
* @param name The widget name of this dialog.
*/
- BackupProfileWidget( TQWidget* tqparent=0, const char* name=0 );
+ BackupProfileWidget( TQWidget* parent=0, const char* name=0 );
/**
* Destroy the backup profile widget.
@@ -57,10 +57,10 @@ public:
* @param archiveName The default name for the new archive.
* @param files The list of files to be archived.
- * @param tqparent The tqparent widget of this dialog.
+ * @param parent The parent widget of this dialog.
* @param name The widget name of this dialog.
*/